You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by ya...@apache.org on 2016/12/08 11:25:24 UTC

mesos git commit: Fixed GMock warning in MasterTest.UnregisteredFrameworksAfterTearDown.

Repository: mesos
Updated Branches:
  refs/heads/master 99b40a224 -> 62ff8047d


Fixed GMock warning in MasterTest.UnregisteredFrameworksAfterTearDown.

Review: https://reviews.apache.org/r/54483/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/62ff8047
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/62ff8047
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/62ff8047

Branch: refs/heads/master
Commit: 62ff8047d9a7eff79197ba4bc9d06ac76691251d
Parents: 99b40a2
Author: Neil Conway <ne...@gmail.com>
Authored: Thu Dec 8 19:24:23 2016 +0800
Committer: Jiang Yan Xu <xu...@apple.com>
Committed: Thu Dec 8 19:24:23 2016 +0800

----------------------------------------------------------------------
 src/tests/master_tests.cpp | 9 +++++++--
 1 file changed, 7 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/62ff8047/src/tests/master_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/master_tests.cpp b/src/tests/master_tests.cpp
index 7442eb8..b3b5630 100644
--- a/src/tests/master_tests.cpp
+++ b/src/tests/master_tests.cpp
@@ -3188,11 +3188,16 @@ TEST_F(MasterTest, UnregisteredFrameworksAfterTearDown)
   EXPECT_CALL(sched, registered(&driver, _, _))
     .WillOnce(FutureSatisfy(&registered));
 
+  Future<vector<Offer>> offers;
+  EXPECT_CALL(sched, resourceOffers(&driver, _))
+    .WillOnce(FutureArg<1>(&offers));
+
   driver.start();
 
   // Wait until the master fully processes framework registration
   // before shutting it down.
   AWAIT_READY(registered);
+  AWAIT_READY(offers);
 
   driver.stop();
   driver.join();
@@ -3188,11 +3188,16 @@ TEST_F(MasterTest, UnregisteredFrameworksAfterTearDown)
   driver.start();
 
-  // Wait until the master fully processes framework registration
-  // before shutting it down.
+  // Wait until the master registers the framework and sends an offer,
+  // before we shutdown the framework.
   AWAIT_READY(registered);